
# NumPy Calculator

A simple Python package that provides basic numerical operations using NumPy.

## Features

- Calculate mean of an array of numbers
- Find maximum value in an array
- Find minimum value in an array  
- Calculate sum of all numbers in an array

## Installation

This package requires Python 3.12 or later.
